function y = conv_new (a, b, shape = "full")

  if (nargin < 2 || nargin > 3)
    print_usage ();
  endif

  if (! (isvector (a) && isvector (b)))
    error ("conv: both arguments A and B must be vectors");
  elseif (nargin == 3 && ! any (strcmpi (shape, {"full", "same", "valid"})))
    error ('conv: SHAPE argument must be "full", "same", or "valid"');
  endif

  y = conv2 (a(:), b(:), shape);

  if (strcmpi (shape, "full"))
    ## Adapt the shape to the longest input argument, if necessary.
    if ((length (a) > length (b) && isrow (a)) ...
        || (length (a) <= length (b) && isrow (b)))
      y = y.';
    endif
  elseif (isrow (a))
    ## Adapt the shape to the first input argument, if necessary.
    y = y.';
  endif

endfunction
